@@ -89,7 +89,7 @@ KMixWindow::KMixWindow(bool invisible, bool reset) :
 	initWidgets();
 	initPrefDlg();
 	DBusMixSetWrapper::initialize(this, QStringLiteral("/Mixers"));
-	MixerToolBox::instance()->initMixer(m_multiDriverMode, m_backendFilter, m_hwInfoString, true);
+	m_hwInfoString = MixerToolBox::initMixer(m_multiDriverMode, m_backendFilter, true);
 	KMixDeviceManager *theKMixDeviceManager = KMixDeviceManager::instance();
 	initActionsAfterInitMixer(); // init actions that require initialized mixer backend(s).
 
@@ -104,10 +104,10 @@ KMixWindow::KMixWindow(bool invisible, bool reset) :
 		setInitialSize();
 
 	fixConfigAfterRead();
+	connect(theKMixDeviceManager, &KMixDeviceManager::plugged, this, &KMixWindow::plugged);
+	connect(theKMixDeviceManager, &KMixDeviceManager::unplugged, this, &KMixWindow::unplugged);
 	theKMixDeviceManager->initHotplug();
-	connect(theKMixDeviceManager, SIGNAL(plugged(const char*,QString,QString&)),
-			SLOT(plugged(const char*,QString,QString&)));
-	connect(theKMixDeviceManager, SIGNAL(unplugged(QString)), SLOT(unplugged(QString)));
+
 	if (m_startVisible && !invisible)
 		show(); // Started visible
 
@@ -115,11 +115,11 @@ KMixWindow::KMixWindow(bool invisible, bool reset) :
 
 	ControlManager::instance().addListener(
 			QString(), // All mixers (as the Global master Mixer might change)
-			(ControlChangeType::Type) (ControlChangeType::ControlList | ControlChangeType::MasterChanged), this,
+			ControlManager::ControlList|ControlManager::MasterChanged, this,
 			"KMixWindow");
 
 	// Send an initial volume refresh (otherwise all volumes are 0 until the next change)
-	ControlManager::instance().announce(QString(), ControlChangeType::Volume, "Startup");
+	ControlManager::instance().announce(QString(), ControlManager::Volume, "Startup");
 }
 
 KMixWindow::~KMixWindow()
@@ -137,7 +137,7 @@ KMixWindow::~KMixWindow()
 	}
 
 	// -2- Mixer HW
-	MixerToolBox::instance()->deinitMixer();
+	MixerToolBox::deinitMixer();
 
 	// -3- Action collection (just to please Valgrind)
 	actionCollection()->clear();
@@ -151,18 +151,17 @@ KMixWindow::~KMixWindow()
 
 }
 
-void KMixWindow::controlsChange(int changeType)
+void KMixWindow::controlsChange(ControlManager::ChangeType changeType)
 {
-	ControlChangeType::Type type = ControlChangeType::fromInt(changeType);
-	switch (type)
+	switch (changeType)
 	{
-	case ControlChangeType::ControlList:
-	case ControlChangeType::MasterChanged:
+	case ControlManager::ControlList:
+	case ControlManager::MasterChanged:
 		updateDocking();
 		break;
 
 	default:
-		ControlManager::warnUnexpectedChangeType(type, this);
+		ControlManager::warnUnexpectedChangeType(changeType, this);
 		break;
 	}
 
@@ -390,7 +389,7 @@ void KMixWindow::saveBaseConfig()
 	config.writeEntry("MasterMixer", master.getCard());
 	config.writeEntry("MasterMixerDevice", master.getControl());
 
-	QString mixerIgnoreExpression = MixerToolBox::instance()->mixerIgnoreExpression();
+	QString mixerIgnoreExpression = MixerToolBox::mixerIgnoreExpression();
 	config.writeEntry("MixerIgnoreExpression", mixerIgnoreExpression);
 
 	qCDebug(KMIX_LOG)
@@ -413,9 +412,9 @@ void KMixWindow::saveViewConfig()
 	for (int i = 0; i < m_wsMixers->count(); ++i)
 	{
 		QWidget *w = m_wsMixers->widget(i);
-		if (w->inherits("KMixerWidget"))
+		KMixerWidget *mw = qobject_cast<KMixerWidget *>(w);
+		if (mw!=nullptr)
 		{
-			KMixerWidget* mw = (KMixerWidget*) w;
 			// Here also Views are saved. even for Mixers that are closed. This is necessary when unplugging cards.
 			// Otherwise the user will be confused afer re-plugging the card (as the config was not saved).
 			mw->saveConfig(KSharedConfig::openConfig().data());
@@ -516,7 +515,7 @@ void KMixWindow::loadBaseConfig()
 	QString masterDev = config.readEntry("MasterMixerDevice", "");
 	Mixer::setGlobalMaster(mixerMasterCard, masterDev, true);
 	QString mixerIgnoreExpression = config.readEntry("MixerIgnoreExpression", "Modem");
-	MixerToolBox::instance()->setMixerIgnoreExpression(mixerIgnoreExpression);
+	MixerToolBox::setMixerIgnoreExpression(mixerIgnoreExpression);
 
 	// --- Advanced options, without GUI: START -------------------------------------
 	QString volumePercentageStepString = config.readEntry("VolumePercentageStep");
@@ -680,17 +679,25 @@ void KMixWindow::recreateGUI(bool saveConfig, const QString& mixerId, bool force
 			foreach ( QString profileId, profileList)
 			{
 				// This handles the profileList form the kmixrc
-				qCDebug(KMIX_LOG) << "Now searching for profile: " << profileId;
+				qCDebug(KMIX_LOG) << "Searching for GUI profile" << profileId;
 				GUIProfile* guiprof = GUIProfile::find(mixer, profileId, true, false);// ### Card specific profile ###
-				if ( guiprof != 0 )
+
+				if (guiprof==nullptr)
+				{
+					qCWarning(KMIX_LOG) << "Cannot load profile" << profileId;
+					if (profileId.startsWith("MPRIS2."))
+					{
+						profileId = "MPRIS2.default";
+						qCDebug(KMIX_LOG) << "For MPRIS2 falling back to" << profileId;
+						guiprof = GUIProfile::find(mixer, profileId, true, false);
+					}
+				}
+
+				if (guiprof!=nullptr)
 				{
 					addMixerWidget(mixer->id(), guiprof->getId(), -1);
 					atLeastOneProfileWasAdded = true;
 				}
-				else
-				{
-					qCCritical(KMIX_LOG) << "Cannot load profile " << profileId << " . It was removed by the user, or the KMix config file is defective.";
-				}
 			}
 
 			if (atLeastOneProfileWasAdded)
@@ -769,7 +776,7 @@ KMixWindow::findKMWforTab(const QString& kmwId)
 {
 	for (int i = 0; i < m_wsMixers->count(); ++i)
 	{
-		KMixerWidget* kmw = (KMixerWidget*) m_wsMixers->widget(i);
+		KMixerWidget *kmw = qobject_cast<KMixerWidget *>(m_wsMixers->widget(i));
 		if (kmw->getGuiprof()->getId() == kmwId)
 		{
 			return kmw;
@@ -871,38 +878,36 @@ void KMixWindow::fixConfigAfterRead()
 	} // if config version < 3
 }
 
-void KMixWindow::plugged(const char* driverName, const QString& udi, QString& dev)
+
+void KMixWindow::plugged(const char *driverName, const QString &udi, int dev)
 {
-	qCDebug(KMIX_LOG)
-	<< "Plugged: dev=" << dev << "(" << driverName << ") udi=" << udi << "\n";
-	QString driverNameString;
-	driverNameString = driverName;
-	int devNum = dev.toInt();
-	Mixer *mixer = new Mixer(driverNameString, devNum);
-	if (mixer != 0)
+	qCDebug(KMIX_LOG) << "dev" << dev << "driver" << driverName << "udi" << udi;
+	Mixer *mixer = new Mixer(QString::fromLocal8Bit(driverName), dev);
+	if (mixer!=nullptr)
 	{
-		qCDebug(KMIX_LOG)
-		<< "Plugged: dev=" << dev << "\n";
-		if (MixerToolBox::instance()->possiblyAddMixer(mixer))
+		if (MixerToolBox::possiblyAddMixer(mixer))
+		{
+			qCDebug(KMIX_LOG) << "adding mixer id" << mixer->id() << "name" << mixer->readableName();
 			recreateGUI(true, mixer->id(), true, false);
+		}
+		else qCWarning(KMIX_LOG) << "Cannot add mixer to GUI";
 	}
 }
 
-void KMixWindow::unplugged(const QString& udi)
+
+void KMixWindow::unplugged(const QString &udi)
 {
-	qCDebug(KMIX_LOG)
-	<< "Unplugged: udi=" << udi << "\n";
+	qCDebug(KMIX_LOG) << "udi" << udi;
 	for (int i = 0; i < Mixer::mixers().count(); ++i)
 	{
 		Mixer *mixer = (Mixer::mixers())[i];
-		//         qCDebug(KMIX_LOG) << "Try Match with:" << mixer->udi() << "\n";
+		// qCDebug(KMIX_LOG) << "Try Match with:" << mixer->udi();
 		if (mixer->udi() == udi)
 		{
-			qCDebug(KMIX_LOG)
-			<< "Unplugged Match: Removing udi=" << udi << "\n";
-			//KMixToolBox::notification("MasterFallback", "aaa");
+			qCDebug(KMIX_LOG) << "Removing mixer";
 			bool globalMasterMixerDestroyed = (mixer == Mixer::getGlobalMasterMixer());
-			// Part 1) Remove Tab
+
+			// Part 1: Remove tab from GUI
 			for (int i = 0; i < m_wsMixers->count(); ++i)
 			{
 				QWidget *w = m_wsMixers->widget(i);
@@ -913,8 +918,12 @@ void KMixWindow::unplugged(const QString& udi)
 					i = -1; // Restart loop from scratch (indices are most likely invalidated at removeTab() )
 				}
 			}
-			MixerToolBox::instance()->removeMixer(mixer);
-			// Check whether the Global Master disappeared, and select a new one if necessary
+
+			// Part 2: Remove mixer from known list
+			MixerToolBox::removeMixer(mixer);
+
+			// Part 3: Check whether the Global Master disappeared,
+			// and select a new one if necessary
 			shared_ptr<MixDevice> md = Mixer::getGlobalMasterMD();
 			if (globalMasterMixerDestroyed || md.get() == 0)
 			{
@@ -993,11 +1002,6 @@ bool KMixWindow::addMixerWidget(const QString& mixer_ID, QString guiprofId, int
 	ViewBase::ViewFlags vflags = ViewBase::HasMenuBar;
 	if ((_actionShowMenubar == 0) || _actionShowMenubar->isChecked())
 		vflags |= ViewBase::MenuBarVisible;
-	if (GlobalConfig::instance().data.getToplevelOrientation() == Qt::Vertical)
-		vflags |= ViewBase::Horizontal;
-	else
-		vflags |= ViewBase::Vertical;
-
 	KMixerWidget *kmw = new KMixerWidget(mixer, this, vflags, guiprofId, actionCollection());
 	/* A newly added mixer will automatically added at the top
 	 * and thus the window title is also set appropriately */
@@ -1200,11 +1204,11 @@ void KMixWindow::applyPrefs()
 	if (dockwidgetHasChanged || toplevelOrientationHasChanged || traypopupOrientationHasChanged)
 	{
 		// These might need a complete relayout => announce a ControlList change to rebuild everything
-		ControlManager::instance().announce(QString(), ControlChangeType::ControlList, QString("Preferences Dialog"));
+		ControlManager::instance().announce(QString(), ControlManager::ControlList, QString("Preferences Dialog"));
 	}
 	else if (labelsHasChanged || ticksHasChanged)
 	{
-		ControlManager::instance().announce(QString(), ControlChangeType::GUI, QString("Preferences Dialog"));
+		ControlManager::instance().announce(QString(), ControlManager::GUI, QString("Preferences Dialog"));
 	}
 	// showOSD does not require any information. It reads on-the-fly from GlobalConfig.
 
@@ -1248,7 +1252,7 @@ void KMixWindow::forkExec(const QStringList& args)
 
 void KMixWindow::slotConfigureCurrentView()
 {
-	KMixerWidget* mw = (KMixerWidget*) m_wsMixers->currentWidget();
+	KMixerWidget *mw = qobject_cast<KMixerWidget *>(m_wsMixers->currentWidget());
 	ViewBase* view = 0;
 	if (mw)
 		view = mw->currentView();
@@ -1284,8 +1288,8 @@ void KMixWindow::slotSelectMaster()
 
 void KMixWindow::newMixerShown(int /*tabIndex*/)
 {
-	KMixerWidget* kmw = (KMixerWidget*) m_wsMixers->currentWidget();
-	if (kmw)
+	KMixerWidget *kmw = qobject_cast<KMixerWidget *>(m_wsMixers->currentWidget());
+	if (kmw!=nullptr)
 	{
 		// I am using the app name as a PREFIX, as KMix is a single window app, and it is
 		// more helpful to the user to see "KDE Mixer" in a window list than a possibly cryptic
