@@ -41,6 +41,7 @@ class KToggleAction;
 
 // KMix
 #include "core/GlobalConfig.h"
+#include "core/ControlManager.h"
 
 class KMixDockWidget;
 class KMixerWidget;
@@ -76,7 +77,7 @@ KMixWindow : public KXmlGuiWindow
    bool queryClose() Q_DECL_OVERRIDE;
 
   public slots:
-   void controlsChange(int changeType);
+   void controlsChange(ControlManager::ChangeType changeType);
    void quit();
    void showSettings();
    void showHelp();
@@ -141,8 +142,10 @@ private:
    void slotHWInfo();
    void slotKdeAudioSetupExec();
    void slotConfigureCurrentView();
-   void plugged( const char* driverName, const QString& udi, QString& dev);
-   void unplugged( const QString& udi);
+
+   void plugged(const char *driverName, const QString &udi, int dev);
+   void unplugged(const QString &udi);
+
    void hideOrClose();
    void slotIncreaseVolume();
    void slotDecreaseVolume();
